// Generated by gir (https://github.com/gtk-rs/gir @ d7c0763cacbc)
// from 
// from gir-files (https://github.com/gtk-rs/gir-files.git @ 4d1189172a70)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "GtkSourceBackgroundPatternType", sizeof(GtkSourceBackgroundPatternType), alignof(GtkSourceBackgroundPatternType));
    printf("%s;%zu;%zu\n", "GtkSourceBracketMatchType", sizeof(GtkSourceBracketMatchType), alignof(GtkSourceBracketMatchType));
    printf("%s;%zu;%zu\n", "GtkSourceBuffer", sizeof(GtkSourceBuffer), alignof(GtkSourceBuffer));
    printf("%s;%zu;%zu\n", "GtkSourceBufferClass", sizeof(GtkSourceBufferClass), alignof(GtkSourceBufferClass));
    printf("%s;%zu;%zu\n", "GtkSourceChangeCaseType", sizeof(GtkSourceChangeCaseType), alignof(GtkSourceChangeCaseType));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionActivation", sizeof(GtkSourceCompletionActivation), alignof(GtkSourceCompletionActivation));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionCellClass", sizeof(GtkSourceCompletionCellClass), alignof(GtkSourceCompletionCellClass));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionClass", sizeof(GtkSourceCompletionClass), alignof(GtkSourceCompletionClass));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionColumn", sizeof(GtkSourceCompletionColumn), alignof(GtkSourceCompletionColumn));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionContextClass", sizeof(GtkSourceCompletionContextClass), alignof(GtkSourceCompletionContextClass));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionProposalInterface", sizeof(GtkSourceCompletionProposalInterface), alignof(GtkSourceCompletionProposalInterface));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionProviderInterface", sizeof(GtkSourceCompletionProviderInterface), alignof(GtkSourceCompletionProviderInterface));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionSnippets", sizeof(GtkSourceCompletionSnippets), alignof(GtkSourceCompletionSnippets));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionSnippetsClass", sizeof(GtkSourceCompletionSnippetsClass), alignof(GtkSourceCompletionSnippetsClass));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionWords", sizeof(GtkSourceCompletionWords), alignof(GtkSourceCompletionWords));
    printf("%s;%zu;%zu\n", "GtkSourceCompletionWordsClass", sizeof(GtkSourceCompletionWordsClass), alignof(GtkSourceCompletionWordsClass));
    printf("%s;%zu;%zu\n", "GtkSourceCompressionType", sizeof(GtkSourceCompressionType), alignof(GtkSourceCompressionType));
    printf("%s;%zu;%zu\n", "GtkSourceFile", sizeof(GtkSourceFile), alignof(GtkSourceFile));
    printf("%s;%zu;%zu\n", "GtkSourceFileClass", sizeof(GtkSourceFileClass), alignof(GtkSourceFileClass));
    printf("%s;%zu;%zu\n", "GtkSourceFileLoaderClass", sizeof(GtkSourceFileLoaderClass), alignof(GtkSourceFileLoaderClass));
    printf("%s;%zu;%zu\n", "GtkSourceFileLoaderError", sizeof(GtkSourceFileLoaderError), alignof(GtkSourceFileLoaderError));
    printf("%s;%zu;%zu\n", "GtkSourceFileSaverClass", sizeof(GtkSourceFileSaverClass), alignof(GtkSourceFileSaverClass));
    printf("%s;%zu;%zu\n", "GtkSourceFileSaverError", sizeof(GtkSourceFileSaverError), alignof(GtkSourceFileSaverError));
    printf("%s;%zu;%zu\n", "GtkSourceFileSaverFlags", sizeof(GtkSourceFileSaverFlags), alignof(GtkSourceFileSaverFlags));
    printf("%s;%zu;%zu\n", "GtkSourceGutterClass", sizeof(GtkSourceGutterClass), alignof(GtkSourceGutterClass));
    printf("%s;%zu;%zu\n", "GtkSourceGutterLinesClass", sizeof(GtkSourceGutterLinesClass), alignof(GtkSourceGutterLinesClass));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRenderer", sizeof(GtkSourceGutterRenderer), alignof(GtkSourceGutterRenderer));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRendererAlignmentMode", sizeof(GtkSourceGutterRendererAlignmentMode), alignof(GtkSourceGutterRendererAlignmentMode));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRendererClass", sizeof(GtkSourceGutterRendererClass), alignof(GtkSourceGutterRendererClass));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRendererPixbuf", sizeof(GtkSourceGutterRendererPixbuf), alignof(GtkSourceGutterRendererPixbuf));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRendererPixbufClass", sizeof(GtkSourceGutterRendererPixbufClass), alignof(GtkSourceGutterRendererPixbufClass));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRendererText", sizeof(GtkSourceGutterRendererText), alignof(GtkSourceGutterRendererText));
    printf("%s;%zu;%zu\n", "GtkSourceGutterRendererTextClass", sizeof(GtkSourceGutterRendererTextClass), alignof(GtkSourceGutterRendererTextClass));
    printf("%s;%zu;%zu\n", "GtkSourceHoverClass", sizeof(GtkSourceHoverClass), alignof(GtkSourceHoverClass));
    printf("%s;%zu;%zu\n", "GtkSourceHoverContextClass", sizeof(GtkSourceHoverContextClass), alignof(GtkSourceHoverContextClass));
    printf("%s;%zu;%zu\n", "GtkSourceHoverDisplayClass", sizeof(GtkSourceHoverDisplayClass), alignof(GtkSourceHoverDisplayClass));
    printf("%s;%zu;%zu\n", "GtkSourceHoverProviderInterface", sizeof(GtkSourceHoverProviderInterface), alignof(GtkSourceHoverProviderInterface));
    printf("%s;%zu;%zu\n", "GtkSourceIndenterInterface", sizeof(GtkSourceIndenterInterface), alignof(GtkSourceIndenterInterface));
    printf("%s;%zu;%zu\n", "GtkSourceLanguageClass", sizeof(GtkSourceLanguageClass), alignof(GtkSourceLanguageClass));
    printf("%s;%zu;%zu\n", "GtkSourceLanguageManagerClass", sizeof(GtkSourceLanguageManagerClass), alignof(GtkSourceLanguageManagerClass));
    printf("%s;%zu;%zu\n", "GtkSourceMap", sizeof(GtkSourceMap), alignof(GtkSourceMap));
    printf("%s;%zu;%zu\n", "GtkSourceMapClass", sizeof(GtkSourceMapClass), alignof(GtkSourceMapClass));
    printf("%s;%zu;%zu\n", "GtkSourceMark", sizeof(GtkSourceMark), alignof(GtkSourceMark));
    printf("%s;%zu;%zu\n", "GtkSourceMarkAttributesClass", sizeof(GtkSourceMarkAttributesClass), alignof(GtkSourceMarkAttributesClass));
    printf("%s;%zu;%zu\n", "GtkSourceMarkClass", sizeof(GtkSourceMarkClass), alignof(GtkSourceMarkClass));
    printf("%s;%zu;%zu\n", "GtkSourceNewlineType", sizeof(GtkSourceNewlineType), alignof(GtkSourceNewlineType));
    printf("%s;%zu;%zu\n", "GtkSourcePrintCompositor", sizeof(GtkSourcePrintCompositor), alignof(GtkSourcePrintCompositor));
    printf("%s;%zu;%zu\n", "GtkSourcePrintCompositorClass", sizeof(GtkSourcePrintCompositorClass), alignof(GtkSourcePrintCompositorClass));
    printf("%s;%zu;%zu\n", "GtkSourceRegion", sizeof(GtkSourceRegion), alignof(GtkSourceRegion));
    printf("%s;%zu;%zu\n", "GtkSourceRegionClass", sizeof(GtkSourceRegionClass), alignof(GtkSourceRegionClass));
    printf("%s;%zu;%zu\n", "GtkSourceRegionIter", sizeof(GtkSourceRegionIter), alignof(GtkSourceRegionIter));
    printf("%s;%zu;%zu\n", "GtkSourceSearchContextClass", sizeof(GtkSourceSearchContextClass), alignof(GtkSourceSearchContextClass));
    printf("%s;%zu;%zu\n", "GtkSourceSearchSettings", sizeof(GtkSourceSearchSettings), alignof(GtkSourceSearchSettings));
    printf("%s;%zu;%zu\n", "GtkSourceSearchSettingsClass", sizeof(GtkSourceSearchSettingsClass), alignof(GtkSourceSearchSettingsClass));
    printf("%s;%zu;%zu\n", "GtkSourceSmartHomeEndType", sizeof(GtkSourceSmartHomeEndType), alignof(GtkSourceSmartHomeEndType));
    printf("%s;%zu;%zu\n", "GtkSourceSnippetChunkClass", sizeof(GtkSourceSnippetChunkClass), alignof(GtkSourceSnippetChunkClass));
    printf("%s;%zu;%zu\n", "GtkSourceSnippetClass", sizeof(GtkSourceSnippetClass), alignof(GtkSourceSnippetClass));
    printf("%s;%zu;%zu\n", "GtkSourceSnippetContextClass", sizeof(GtkSourceSnippetContextClass), alignof(GtkSourceSnippetContextClass));
    printf("%s;%zu;%zu\n", "GtkSourceSnippetManagerClass", sizeof(GtkSourceSnippetManagerClass), alignof(GtkSourceSnippetManagerClass));
    printf("%s;%zu;%zu\n", "GtkSourceSortFlags", sizeof(GtkSourceSortFlags), alignof(GtkSourceSortFlags));
    printf("%s;%zu;%zu\n", "GtkSourceSpaceDrawerClass", sizeof(GtkSourceSpaceDrawerClass), alignof(GtkSourceSpaceDrawerClass));
    printf("%s;%zu;%zu\n", "GtkSourceSpaceLocationFlags", sizeof(GtkSourceSpaceLocationFlags), alignof(GtkSourceSpaceLocationFlags));
    printf("%s;%zu;%zu\n", "GtkSourceSpaceTypeFlags", sizeof(GtkSourceSpaceTypeFlags), alignof(GtkSourceSpaceTypeFlags));
    printf("%s;%zu;%zu\n", "GtkSourceStyleClass", sizeof(GtkSourceStyleClass), alignof(GtkSourceStyleClass));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeChooserButton", sizeof(GtkSourceStyleSchemeChooserButton), alignof(GtkSourceStyleSchemeChooserButton));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeChooserButtonClass", sizeof(GtkSourceStyleSchemeChooserButtonClass), alignof(GtkSourceStyleSchemeChooserButtonClass));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeChooserInterface", sizeof(GtkSourceStyleSchemeChooserInterface), alignof(GtkSourceStyleSchemeChooserInterface));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeChooserWidget", sizeof(GtkSourceStyleSchemeChooserWidget), alignof(GtkSourceStyleSchemeChooserWidget));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeChooserWidgetClass", sizeof(GtkSourceStyleSchemeChooserWidgetClass), alignof(GtkSourceStyleSchemeChooserWidgetClass));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeClass", sizeof(GtkSourceStyleSchemeClass), alignof(GtkSourceStyleSchemeClass));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemeManagerClass", sizeof(GtkSourceStyleSchemeManagerClass), alignof(GtkSourceStyleSchemeManagerClass));
    printf("%s;%zu;%zu\n", "GtkSourceStyleSchemePreviewClass", sizeof(GtkSourceStyleSchemePreviewClass), alignof(GtkSourceStyleSchemePreviewClass));
    printf("%s;%zu;%zu\n", "GtkSourceTag", sizeof(GtkSourceTag), alignof(GtkSourceTag));
    printf("%s;%zu;%zu\n", "GtkSourceTagClass", sizeof(GtkSourceTagClass), alignof(GtkSourceTagClass));
    printf("%s;%zu;%zu\n", "GtkSourceView", sizeof(GtkSourceView), alignof(GtkSourceView));
    printf("%s;%zu;%zu\n", "GtkSourceViewClass", sizeof(GtkSourceViewClass), alignof(GtkSourceViewClass));
    printf("%s;%zu;%zu\n", "GtkSourceViewGutterPosition", sizeof(GtkSourceViewGutterPosition), alignof(GtkSourceViewGutterPosition));
    printf("%s;%zu;%zu\n", "GtkSourceVimIMContextClass", sizeof(GtkSourceVimIMContextClass), alignof(GtkSourceVimIMContextClass));
    return 0;
}
